The County Court deals with civil (non-criminal) matters.

Unlike criminal cases, in which the state prosecutes an individual, civil court cases arise where an individual or a business believes their rights have been infringed.

This court began to occasionally transfer select judgments to The National Archives in 2024. The oldest judgment from this court included in Find Case Law is from {start_year}.

You can read more about it on the [County Court page](https://www.gov.uk/courts-tribunals/court-of-protection){target="\_blank"} on the [HM Courts and Tribunals Service website](https://www.judiciary.uk/){target="\_blank"}.
